﻿
CREATE TABLE MitarbeiterIn (
	pnr INTEGER PRIMARY KEY,
	name VARCHAR (40) NOT NULL,
	svnr INTEGER NOT NULL,
	anschrift VARCHAR(40) NOT NULL,
	seit DATE NOT NULL
);

CREATE TABLE Restaurant (
	restnr INTEGER NOT NULL,
	standort VARCHAR(20) NOT NULL,
	leiter INTEGER NOT NULL,	
	CONSTRAINT fk_leiter FOREIGN KEY (leiter) REFERENCES Mitarbeiterin(pnr),
	CONSTRAINT restaurant_pk PRIMARY KEY (restnr, standort) 
);

CREATE TABLE arbeitet (
	restnr INTEGER NOT NULL,
	standort VARCHAR(20) NOT NULL,
	pnr INTEGER NOT NULL,	
	CONSTRAINT fk_pnr FOREIGN KEY (pnr) REFERENCES MitarbeiterIn(pnr),
	CONSTRAINT fk_restaurant FOREIGN KEY (restnr, standort) REFERENCES Restaurant(restnr, standort),
	CONSTRAINT arbeitet_pk PRIMARY KEY(restnr, standort, pnr)
);

CREATE TABLE Befristung (
	pnr INTEGER NOT NULL,
	bis DATE NOT NULL,
	CONSTRAINT fk_pnr_befristung FOREIGN KEY (pnr) REFERENCES MitarbeiterIn(pnr),
	CONSTRAINT pk_befristung PRIMARY KEY (pnr)
);

CREATE TABLE KellnerIn (
	pnr INTEGER NOT NULL,
	CONSTRAINT fk_pnr_kellnerin FOREIGN KEY (pnr) REFERENCES MitarbeiterIn(pnr),
	CONSTRAINT pk_kellnerin PRIMARY KEY (pnr)
);

CREATE TABLE Gericht (
	id INTEGER PRIMARY KEY,
	name VARCHAR(20) NOT NULL,
	preis NUMERIC(7,2) NOT NULL
);

CREATE TABLE Tisch (
	restnr INTEGER NOT NULL,
	standort VARCHAR(20) NOT NULL,
	tischnr INTEGER NOT NULL,
	zustaendig INTEGER REFERENCES KellnerIn(pnr),
	CONSTRAINT fk_restaurant_tisch FOREIGN KEY (restnr, standort) REFERENCES Restaurant(restnr, standort),
	CONSTRAINT pk_tisch PRIMARY KEY (restnr, standort, tischnr)
);

CREATE TABLE Kunde (
	id INTEGER PRIMARY KEY,
	telefon VARCHAR(20) NOT NULL,
	name VARCHAR(20) NOT NULL
);

CREATE TABLE Event (
	datum DATE PRIMARY KEY,
	thema VARCHAR(20) NOT NULL
);

CREATE TABLE teilnehmen (
	id INTEGER REFERENCES Kunde(id),
	datum DATE REFERENCES Event(datum),
	tischnr INTEGER NOT NULL,
	restnr INTEGER NOT NULL,
	standort VARCHAR(20) NOT NULL,
	CONSTRAINT fk_tisch_teilnehmen FOREIGN KEY (tischnr, restnr, standort) REFERENCES Tisch(tischnr, restnr, standort),
	CONSTRAINT pk_teilnehmen PRIMARY KEY(id, datum, tischnr, restnr, standort)
);

CREATE TABLE Bestellung (
	bestnr INTEGER PRIMARY KEY,
	tischnr INTEGER NOT NULL,
	restnr INTEGER NOT NULL,
	standort VARCHAR(20) NOT NULL,
	CONSTRAINT fk_tisch_bestellung FOREIGN KEY (tischnr, restnr, standort) REFERENCES Tisch(tischnr, restnr, standort)
);

CREATE TABLE beinhaltet (
	bestnr INTEGER REFERENCES Bestellung(bestnr),
	id INTEGER REFERENCES Gericht(id),
	stueck INTEGER DEFAULT 1,
	CONSTRAINT pk_beinhaltet PRIMARY KEY (bestnr, id)
);
